@@ -2,7 +2,7 @@
 from elastictex import api
 from flask import Flask, request, render_template
 
-app = Flask(__name__)
+app = Flask(__name__, )
 
 
 def main():
@@ -14,7 +14,7 @@ def main():
 
     print(host)
     api.init(host)
-    app.run(debug=True)
+    app.run(debug=True, post=9999)
 
 
 @app.route('/')
